==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/actions/mesh/basicmesh/RenderingOption.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef RENDERING_OPTION_H
#define RENDERING_OPTION_H

#include <QObject>
#include <Action.h>
#include <ActionWidget.h>

/** An operator to change the way mesh are visualized */
class RenderingOption : public camitk::Action {
    Q_OBJECT

public:
    /// the constructor
    RenderingOption(camitk::ActionExtension*);

    /// the destructor
    virtual ~RenderingOption();

    /// use the default widget
    virtual QWidget* getWidget();

public slots:
    /// update the rendering depending on the button states
    virtual ApplyStatus apply();

};


#endif // RENDERING_OPTION_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/mesh/basicmesh/RenderingOption.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef RENDERING_OPTION_H
#define RENDERING_OPTION_H

#include <QObject>
#include <Action.h>
#include <ActionWidget.h>

/**
 * @ingroup group_sdk_actions_mesh_basicmesh
 * 
 * @brief
 * An operator to change the way mesh are visualized.
 * 
 * \image html actions/basic_mesh_rendering_option.png "The rendering optionwidget." width=10cm
 *  
 */
class RenderingOption : public camitk::Action {
    Q_OBJECT

public:
    /// the constructor
    RenderingOption(camitk::ActionExtension*);

    /// the destructor
    virtual ~RenderingOption();

    /// use the default widget
    virtual QWidget* getWidget();

public slots:
    /// update the rendering depending on the button states
    virtual ApplyStatus apply();

};


#endif // RENDERING_OPTION_H
